<?php
/**
 * Plugin Name: Home Trending Posts Widget
 */

add_action( 'widgets_init', 'mvp_trend_load_widgets' );

function mvp_trend_load_widgets() {
	register_widget( 'mvp_trend_widget' );
}

class mvp_trend_widget extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function __construct() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'mvp_trend_widget', 'description' => esc_html__('A widget that allows you to display a list of Trending Posts.', 'jawn') );

		/* Widget control settings. */
		$control_ops = array( 'width' => 250, 'height' => 350, 'id_base' => 'mvp_trend_widget' );

		/* Create the widget. */
		parent::__construct( 'mvp_trend_widget', esc_html__('Jawn: Home Trending Posts Widget', 'jawn'), $widget_ops, $control_ops );
	}

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		global $post;
		$title = apply_filters('widget_title', $instance['title'] );
		$popular_days = $instance['popular_days'];
		$number = $instance['number'];
		$latest = $instance['latest'];
		$latest_num = $instance['latest_num'];
		$layout = $instance['layout'];
		$code = $instance['code'];

		/* Before widget (defined by themes). */
		echo html_entity_decode($before_widget);

		?>

		<div class="mvp-widget-trend-wrap relative">
			<?php if ($title) { ?>
				<div class="mvp-widget-trend-title">
					<span class="mvp-widget-trend-head"><?php echo esc_html($title); ?></span>
				</div><!--mvp-widget-trend-title-->
			<?php } ?>
			<div class="mvp-widget-trend-grid">
				<?php $popular_days_ago = "$popular_days days ago"; $recent = new WP_Query(array( 'posts_per_page' => $number, 'ignore_sticky_posts'=> 1, 'orderby' => 'meta_value_num', 'order' => 'DESC', 'meta_key' => 'post_views_count', 'date_query' => array( array( 'after' => $popular_days_ago )) )); while($recent->have_posts()) : $recent->the_post(); ?>
					<div class="mvp-widget-trend-story">
						<a href="<?php the_permalink(); ?>" rel="bookmark">
							<div class="mvp-widget-trend-img">
								<?php if (  (function_exists('has_post_thumbnail')) && (has_post_thumbnail())  ) { ?>
									<?php the_post_thumbnail('mvp-mid-thumb'); ?>
								<?php } ?>
							</div><!--mvp-widget-trend-img-->
							<div class="mvp-widget-trend-text">
								<h3 class="mvp-cat-bub"><span class="mvp-cat-bub"><?php $category = get_the_category(); echo esc_html( $category[0]->cat_name ); ?></span></h3>
								<h2><?php the_title(); ?></h2>
							</div><!--mvp-widget-trend-text-->
						</a>
					</div><!--mvp-widget-trend-story-->
				<?php endwhile; wp_reset_postdata(); ?>
			</div><!--mvp-widget-trend-grid-->
			<?php if($latest) { ?>
				<?php if($code) { ?>
					<div class="mvp-widget-latest-wrap mvp-widget-ad-grid">
						<?php if ($layout == 'row') { ?>
							<div class="mvp-widget-latest-main">
						<?php } else { ?>
							<div class="mvp-widget-latest-main mvp-blog-main-grid">
						<?php } ?>
							<?php global $do_not_duplicate; $recent_widget = new WP_Query(array( 'posts_per_page' => $latest_num, 'post__not_in'=>$do_not_duplicate, 'ignore_sticky_posts'=> 1 )); while($recent_widget->have_posts()) : $recent_widget->the_post(); $do_not_duplicate[] = $post->ID; if (isset($do_not_duplicate)) { ?>
								<?php get_template_part( 'parts/blog', 'widget' ); ?>
							<?php } endwhile; wp_reset_postdata(); ?>
						</div><!--mvp-widget-latest-main-->
						<div class="mvp-widget-latest-side">
							<div class="mvp-widget-ad left relative">
								<span class="mvp-ad-label"><?php esc_html_e( 'Advertisement', 'jawn' ); ?></span>
								<?php echo html_entity_decode($code); ?>
							</div><!--mvp-widget-ad-->
						</div><!--mvp-widget-latest-side-->
					</div><!--mvp-widget-latest-wrap-->
				<?php } else { ?>
					<div class="mvp-widget-latest-wrap">
						<?php if ($layout == 'row') { ?>
							<div class="mvp-widget-latest-main">
						<?php } else { ?>
							<div class="mvp-widget-latest-main mvp-blog-main-grid">
						<?php } ?>
							<?php global $do_not_duplicate; $recent_widget = new WP_Query(array( 'posts_per_page' => $latest_num, 'post__not_in'=>$do_not_duplicate, 'ignore_sticky_posts'=> 1 )); while($recent_widget->have_posts()) : $recent_widget->the_post(); $do_not_duplicate[] = $post->ID; if (isset($do_not_duplicate)) { ?>
								<?php get_template_part( 'parts/blog', 'widget' ); ?>
							<?php } endwhile; wp_reset_postdata(); ?>
						</div><!--mvp-widget-latest-main-->
					</div><!--mvp-widget-latest-wrap-->
				<?php } ?>
			<?php } ?>
		</div><!--mvp-widget-trend-wrap-->

		<?php

		/* After widget (defined by themes). */
		echo html_entity_decode($after_widget);

	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['popular_days'] = strip_tags( $new_instance['popular_days'] );
		$instance['number'] = strip_tags( $new_instance['number'] );
		$instance['latest'] = strip_tags( $new_instance['latest'] );
		$instance['latest_num'] = strip_tags( $new_instance['latest_num'] );
		$instance['layout'] = strip_tags( $new_instance['layout'] );
		$instance['code'] = $new_instance['code'];

		return $instance;
	}


	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'title' => 'Trending Now', 'popular_days' => '9999', 'number' => '5', 'latest_num' => '4' );
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo esc_html($this->get_field_id( 'title' )); ?>">Title:</label>
			<input id="<?php echo esc_html($this->get_field_id( 'title' )); ?>" name="<?php echo esc_html($this->get_field_name( 'title' )); ?>" value="<?php echo esc_html($instance['title']); ?>" style="width:90%;" />
		</p>

		<!-- Number of days -->
		<p>
			<label for="<?php echo esc_html($this->get_field_id( 'popular_days' )); ?>">Number of days to use for Trending Posts:</label>
			<input id="<?php echo esc_html($this->get_field_id( 'popular_days' )); ?>" name="<?php echo esc_html($this->get_field_name( 'popular_days' )); ?>" value="<?php echo esc_html($instance['popular_days']); ?>" size="3" />
		</p>

		<!-- Number of posts -->
		<p>
			<label for="<?php echo esc_html($this->get_field_id( 'number' )); ?>">Number of Trending Posts to display:</label>
			<input id="<?php echo esc_html($this->get_field_id( 'number' )); ?>" name="<?php echo esc_html($this->get_field_name( 'number' )); ?>" value="<?php echo esc_html($instance['number']); ?>" size="3" />
		</p>

		<!-- Latest Posts -->
		<p>
			<label for="<?php echo esc_html($this->get_field_id( 'latest' )); ?>">Show Latest Posts?</label>
			<input type="checkbox" id="<?php echo esc_html($this->get_field_id( 'latest' )); ?>" name="<?php echo esc_html($this->get_field_name( 'latest' )); ?>" <?php checked( (bool) esc_html($instance['latest']), true ); ?> />
		</p>

		<!-- Number of Latest Posts -->
		<p>
			<label for="<?php echo esc_html($this->get_field_id( 'latest_num' )); ?>">Number of Latest Posts to display:</label>
			<input id="<?php echo esc_html($this->get_field_id( 'latest_num' )); ?>" name="<?php echo esc_html($this->get_field_name( 'latest_num' )); ?>" value="<?php echo esc_html($instance['latest_num']); ?>" size="3" />
		</p>

		<!-- Latest Layout -->
		<p>
			<label for="<?php echo esc_html($this->get_field_id('layout')); ?>">Latest Posts Layout:</label>
			<select id="<?php echo esc_html($this->get_field_id('layout')); ?>" name="<?php echo esc_html($this->get_field_name('layout')); ?>" style="width:100%;">
				<option value='row' <?php if ('row' == $instance['layout']) echo 'selected="selected"'; ?>>Row</option>
				<option value='grid' <?php if ('grid' == $instance['layout']) echo 'selected="selected"'; ?>>Grid</option>
			</select>
		</p>
			
		<!-- Ad code -->
		<p>
			<label for="<?php echo esc_html($this->get_field_id( 'code' )); ?>">Optional Ad Code:</label>
			<textarea id="<?php echo esc_html($this->get_field_id( 'code' )); ?>" name="<?php echo esc_html($this->get_field_name( 'code' )); ?>" style="width:96%;" rows="6"><?php echo html_entity_decode($instance['code']); ?></textarea>
		</p>

	<?php
	}
}

?>